#
# spec file for package nss-mdns
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nss-mdns
Version:        0.15.1
Release:        1.8
Summary:        Host Name Resolution Via Multicast DNS (Zeroconf) for glibc
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/DNS/Utilities
URL:            https://github.com/lathiat/nss-mdns
Source0:        https://github.com/lathiat/nss-mdns/releases/download/v%{version}/nss-mdns-%{version}.tar.gz
Source1:        nss-mdns-config
Source2:        baselibs.conf
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(check)
Requires:       avahi
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         grep
# needed by nss-mdns-config
PreReq:         sed

%description
nss-mdns is a plug-in for the GNU Name Service Switch (NSS)
functionality of the GNU C Library (glibc) providing a hostname
resolution via Multicast DNS (aka Zeroconf, aka Apple Rendezvous, aka
Apple Bonjour), and effectively allowing name resolution by common
Unix/Linux programs in the ad-hoc mDNS domain .local.

nss-mdns provides only client functionality, which means that you have
to run a mDNS responder daemon separately from nss-mdns if you want to
register the local hostname via mDNS. I recommend Avahi.

By default, nss-mdns tries to contact a running avahi-daemon to resolve
hostnames and addresses and makes use of its superior record cacheing.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
install -D -m0755 %{SOURCE1} %{buildroot}%{_sbindir}/nss-mdns-config

%check
make %{?_smp_mflags} check || (cat ./test-suite.log; false)

%post
/sbin/ldconfig
if [ "$1" -eq 1 ] ; then
    # Only enable on first install, to not overwrite changes done by users
    nss-mdns-config --enable
fi

%preun
if [ "$1" -eq 0 ] ; then
    # Completely disable when not upgrading (ie, fully uninstalling)
    nss-mdns-config --disable
fi

%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md NEWS.md ACKNOWLEDGEMENTS.md
%{_sbindir}/nss-mdns-config
%{_libdir}/libnss_mdns.so.2
%{_libdir}/libnss_mdns_minimal.so.2
%{_libdir}/libnss_mdns4.so.2
%{_libdir}/libnss_mdns4_minimal.so.2
%{_libdir}/libnss_mdns6.so.2
%{_libdir}/libnss_mdns6_minimal.so.2

%changelog
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- Update to version 0.15.1:
  + Updated README.md for clarity
  + The return of BSD support!
  + Support for `AVAHI_SOCKET` in `/run` (instead of legacy
    `/var/run`).
* Tue May 19 2020 Andreas Schwab <schwab@suse.de>
- nss-mdns-config: Use /usr/etc/nsswitch.conf as input if
  /etc/nsswitch.conf doesn't exist yet
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Move libraries into the standard dir (/usr/lib*).
  nss_winbind already lives there, which I take as an indicator
  this move will work.
* Thu Mar 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.14.1:
  + No code changes.
  + Fix unit tests to properly work on s390x.
- Changes from version 0.14.0:
  + Fix -Wformat-truncation problem during reading of the allow
    file.
- Changes from version 0.13.2:
  + No code changes.
  + Change how ./configure --enable/disable-tests works:
  - --enable-tests: tests are enabled and will fail if
    dependencies are not found.
  - --disable-tests: tests are not enabled and will not be built
    even if dependencies are found.
  - no flag given: tests are conditionally enabled if
    dependencies are found.
- Changes from version 0.13.1:
  + Very minor code changes (should result in no binary changes).
  + Reformat source to 80 columns.
  + Improve configure options to allow disabling tests even if the
    testing libraries are present.
  + Automake is now non-recursive.
  + Hardcoded paths are now exposed as configure variables.
- Changes from version 0.13:
  + Fix an old memory leak in reverse lookup.
  + Fix the broken workaround for nscd segfaults (not all clients
    would see all results).
  + Simplify buffer management.
  + More unit tests, more cleanups, and fewer gotos.
- Changes from version 0.12:
  + Fix segfault when using nscd.
  + Remove untested, unmaintained BSD support (please help out if
    you would like BSD support to return!).
- Changes from version 0.11:
  + Moved to new GitHub location, docs migrated to markdown.
  + The long-deprecated LEGACY mode is removed.
  + The long-deprecated HONOUR_SEARCH_DOMAINS option is removed.
  + Unit tests are now included, with make check.
  + nss-mdns now implements standard heuristics for detecting
    .local unicast resolution and will automatically disable
    resolution when a local server responds to .local requests.
  + _nss_mdns_gethostbyname3_r and _nss_mdns_gethostbyname4_r are
    now implemented.
  + Full dual-stack IPv4/IPv6 support is implemented.
- Run spec-cleaner, modernize spec.
- Update URL and Source to new upstream home.
- Drop unaligned.diff: Fixed upstream.
- Add pkgconfig(check) BuildRequires and make_check macro, run
  buildtime tests.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Oct 18 2014 Led <ledest@gmail.com>
- Fix bashisms in nss-mdns-config.
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Jul 11 2012 vuntz@opensuse.org
- Add nss-mdns-config script as a source, and install it in
  /usr/sbin: this script can be used to enable/disable mdns in
  /etc/nsswitch.conf (-4/-6 can be used to restrict
  enabling/disabling to IPv4/IPv6).
- Change %%post/%%preun scriptlets to use new nss-mdns-config script
  instead of custom perl-fu.
- Do not restrict mdns support in /etc/nsswitch.conf to IPv4: just
  pass --enable to nss-mdns-config in %%post. Fix bnc#710231.
- Only call nss-mdns-config in %%post on first install, to avoid
  overwriting changes done by users. Fix nss-mdns side of
  bnc#729796.
- Do not call sed to change /etc/nsswitch.conf to remove services
  not provided by nss-mdns anymore: when we need this, we'll be
  able to integrate this in nss-mdns-config.
* Tue Dec 15 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Fri May  1 2009 vuntz@novell.com
- Remove AutoReqProv: it's default now.
- Also fix a typo in the description.
* Mon Oct 13 2008 ro@suse.de
- simplify and correct baselibs.conf
* Wed May 28 2008 olh@suse.de
- change the recommends for XXbit packages to a supplements
  add a Conflicts: != version to the XXbit packages, to give a hint
  during manual package upgrades (bnc#336678)
* Tue Apr 22 2008 coolo@suse.de
- degrading the requires to recommends. It's very well possible
  to install a system with just 64bit
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 hpj@suse.de
- Upgraded to version 0.10:
  * Ported to FreeBSD.
  * Alignment fixes for SPARC.
* Mon Sep 10 2007 ro@suse.de
- modify last change:
  - require 32bit variant on x86_64 and s390x
  - require 64bit variant on ppc
* Mon Sep 10 2007 sbrabec@suse.cz
- Fixed invalid dependency for bi-arch (#309193).
* Thu Sep  6 2007 mauro@suse.de
- Sync the spec with the scripts in the comment #6 of bnc #287583
* Wed Sep  5 2007 mauro@suse.de
- The 64 bit version of nss-mdns will require the -32 version to
  bugfix bnc #287583.
* Sat Apr 21 2007 schwab@suse.de
- Fix unaligned access.
* Tue Feb 20 2007 sbrabec@suse.cz
- New SuSE package, version 0.9.
